@@ -2,7 +2,7 @@
 package Data::Hopen::G::Runnable;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011'; # TRIAL
+our $VERSION = '0.000014'; # TRIAL
 
 use Data::Hopen;
 use Data::Hopen::Scope::Hash;
@@ -24,10 +24,12 @@ Anything with L</run> inherits from this.  TODO should this be a role?
 
 =head2 need
 
+(B<Not currently used>)
 Inputs this Runnable requires.
 A L<Data::Hopen::Util::NameSet>, with the restriction that C<need> may not
 contain regexes.  ("Sorry, I can't run unless you give me every variable
 in the world that starts with Q."  I don't think so!)
+Or maybe later an arrayref?  TODO.
 
 =head2 scope
 
@@ -37,8 +39,10 @@ mechanism in hopen.
 
 =head2 want
 
+(B<Not currently used>)
 Inputs this Runnable accepts but does not require.
 A L<Data::Hopen::Util::NameSet>, which may include regexes.
+Or maybe later an arrayref?  TODO.
 
 =cut
 
@@ -76,10 +80,17 @@ values in the C<context>.
 
 If given, the phase that is currently under way in a build-system run.
 
-=item -generator
+=item -visitor
 
-If given, the L<Data::Hopen::Gen> instance in use for the current
-build-system run.
+If given, an instance that supports C<visit_goal()> and C<visit_node()> calls.
+A L<Data::Hopen::G::DAG> instance invokes those calls after processing each
+goal or other node, respectively.  They are invoked I<after> the goal or
+node has run.  They are, however, given access to the L<Data::Hopen::Scope>
+that the node used for its inputs, in the C<$node_inputs> parameter.  Example:
+
+    $visitor->visit_goal($goal, $node_inputs);
+
+The return value from C<visit_goal()> or C<visit_node()> is ignored.
 
 =item -nocontext
 
@@ -94,18 +105,21 @@ scope.
 =cut
 
 sub run {
-    my ($self, %args) = getparameters('self', [qw(; context phase generator nocontext)], @_);
+    my ($self, %args) = getparameters('self', [qw(; context phase visitor nocontext)], @_);
     my $context_scope = $args{context};     # which may be undef - that's OK
     croak "Can't combine -context and -nocontext" if $args{context} && $args{nocontext};
 
     # Link the outer scope to our scope
     my $saver = $args{nocontext} ? undef : $self->scope->outerize($context_scope);
 
-    hlog { ref($self), $self->name, 'input', Dumper($self->scope->as_hashref) } 3;
+    hlog { '->', ref($self), $self->name, 'input', Dumper($self->scope->as_hashref) } 3;
 
-    my $retval = $self->_run(forward_opts(\%args, {'-'=>1}, qw[phase generator]));
+    my $retval = $self->_run(forward_opts(\%args, {'-'=>1}, qw[phase visitor]));
 
-    hlog { ref $self, $self->name, 'output', Dumper($retval) } 3;
+    die "$self\->_run() did not return a hashref" unless ref $retval eq 'HASH';
+        # Prevent errors about `non-hashref 1` or `invalid key`.
+
+    hlog { '<-', ref $self, $self->name, 'output', Dumper($retval) } 3;
 
     return $retval;
 } #run()
@@ -116,13 +130,14 @@ The internal method that implements L</run>.  Must be implemented by
 subclasses.  When C<_run> is called, C<< $self->scope >> has been hooked
 to the context scope, if any.
 
-Parameters are C<-phase> and C<-generator>.  C<_run> is always called in scalar
-context, and must return a new hashref.
+Parameters are C<-phase> and C<-visitor>, and are always passed by name
+(C<< -phase=>$p, -visitor=>$v >>).  C<_run> is always called in scalar context,
+and B<must> return a new hashref.
 
 =cut
 
 sub _run {
-    my ($self, %args) = getparameters('self', [qw(; phase generator)], @_);
+    my ($self, %args) = getparameters('self', [qw(; phase visitor)], @_);
     ...
 }
 
