@@ -1,8 +1,9 @@
 # Data::Hopen::Scope::Environment - a hopen Scope for %ENV
+# TODO handle $set == FIRST_ONLY
 package Data::Hopen::Scope::Environment;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011'; # TRIAL
+our $VERSION = '0.000014'; # TRIAL
 
 use parent 'Data::Hopen::Scope';
 
@@ -24,6 +25,8 @@ with L<Data::Hopen::Scope::Hash>.
 
 =head1 METHODS
 
+Note: L<Data::Hopen::Scope/merge> is unsupported.
+
 =cut
 
 # }}}1
@@ -56,14 +59,14 @@ sub _find_here {
     return ($args{set} eq '*') ? { 0 => $val } : $val;
 } #_find_here()
 
-=head2 add
+=head2 put
 
 Updates the corresponding environment variables, in order, by setting C<$ENV{}>.
 Returns the instance.
 
 =cut
 
-sub add {
+sub put {
     my $self = shift;
     croak "Got an odd number of parameters" if @_%2;
     while(@_) {
@@ -83,7 +86,8 @@ sub _names_here {
     my ($self, %args) = getparameters('self', [qw(retval ; set)], @_);
     _set0 $args{set} or croak 'I only support set 0';
     $args{retval}->insert(keys %ENV);
-    hlog { __PACKAGE__ . '::_names_here', Dumper $args{retval} };
+    hlog { __PACKAGE__ . '::_names_here', Dumper $args{retval} } 9;
+        # Don't usually log, since the environment is often fairly hefty!
 } #_names_here()
 
 1;
